#!/bin/bash

DIRECTORY=/data/sensor-data
LOG_FILE=$DIRECTORY/sd_uninstall.log
HOST_DATA_DIR_CONFIG=$DIRECTORY/config
HOST_DATA_DIR_DB=$DIRECTORY/db
HOST_DATA_DIR_LOGS=$DIRECTORY/logs
CONTAINER_NAME=sensor-data
APP_VERSION=1.0.1
APP_IMAGE=vofo/$CONTAINER_NAME:$APP_VERSION

PORT=6002

preCheck() {
    
    if ! command -v tee > /dev/null; then
        echo "`date` tee command not found. Please install tee." >> $LOG_FILE
        exit 1
    fi
    
    if ! command -v docker-compose > /dev/null; then
        echo "`date` docker-compose command not found. Please install docker-compose." | tee -a $LOG_FILE
        exit 1
    fi
    
    if ! command -v docker > /dev/null; then
        echo "`date` docker command not found. Please install docker." | tee -a $LOG_FILE
        exit 1
    fi
    return 0
}

uninstall() {
    # Stop sensor-data
    docker stop $CONTAINER_NAME
    echo "`date` wait 10 seconds for $CONTAINER_NAME to stop" | tee -a $LOG_FILE
    sleep 10

    #delete sensor-data
    docker rm $CONTAINER_NAME
    
    # Clear docker images
    docker rmi $APP_IMAGE
    
    # Clear data
    rm -rf $HOST_DATA_DIR_DB
    rm -rf $HOST_DATA_DIR_LOGS
    return 0
}

postCheck() {
    echo "`date` start post check for $CONTAINER_NAME uninstallation" | tee -a $LOG_FILE
    
    # Check sensor-data status
    if docker-compose ps | grep $CONTAINER_NAME | grep Up > /dev/null; then
        echo "`date` sensor-data is running." | tee -a $LOG_FILE
        return 1
    fi

    # Clear docker images
    if docker images | grep $CONTAINER_NAME | grep $APP_VERSION > /dev/null; then
        echo "`date` sensor-data image is not removed." | tee -a $LOG_FILE
        return 1
    fi

    if [ -d "$HOST_DATA_DIR_DB" ]; then
        echo "`date` sensor-data db data is not removed." | tee -a $LOG_FILE
        return 1
    fi

    if [ -d "$HOST_DATA_DIR_LOGS" ]; then
        echo "`date` sensor-data log data is not removed." | tee -a $LOG_FILE
        return 1
    fi
    
    return 0
}

# step 1: pre-Check
preCheck
preCheckResult=$?
echo "`date` pre check result is $preCheckResult" | tee -a $LOG_FILE
if [ $preCheckResult -eq 0 ]
then
    echo "`date` Pre-check successful." | tee -a $LOG_FILE
    # Step 2: Uninstall sensor-data
    uninstall
    uninstallResult=$?
    if [ $uninstallResult -eq 0 ]
    then
        echo "`date` Uninstall sensor-data successful." | tee -a $LOG_FILE
        # Step 3: Post-check
        postCheck
        postCheckResult=$?
        if [ $postCheckResult -eq 0 ]
        then
            echo "`date` Post-check successful." | tee -a $LOG_FILE
            echo "`date` sensor-data uninstallation process completed." | tee -a $LOG_FILE
            exit 0
        else
            echo "`date` Post-check failed." | tee -a $LOG_FILE
            exit 9
        fi
    else
        echo "`date` Uninstall sensor-data failed." | tee -a $LOG_FILE
        exit 8
    fi
else
    echo "`date` Pre-check failed." | tee -a $LOG_FILE
    exit 7
fi